function expInp = expandInp(csArray, noU, noI, noW)
%Diese Methode erzeugt aus einem gegebenen Muster-Vektor
%in dem die An- und Abwesenheit der CS kodiert ist, einen
%der Netzspezifikation entsprechenden Input Vektor.

%Ein Feld der entsprechenden Lnge anlegen, auf dem man
%dann arbeiten kann.
expInp = zeros(1, noW);

noCS = length(csArray);
%Anzahl von Unique-Cues pro CS
noUCpCS = (noCS - 1) * noI;

%zuerst wird fr jeden CS ein Vektor gebildet, so da
%der Ergebnisvektor sich durch die Addition und geeignete
%Nachverarbeitung des Summenvektors ergibt.
absOffset = noCS * noU;
for i = 1:noCS
   aktCS = csArray(i);
   
   %grundstzlich sind bei Anwesenheit des CS alle seine Units gesetzt.
   expInp((((i-1)*noU)+1) : i * noU) = expInp((((i-1)*noU)+1) : i * noU) + repmat(aktCS, 1, noU);
   
   %die entsprechenden Units potentiell anderer anwesender CS
   %mssen gehemmt werden.
   for j = 1:noCS
      %Beginn der CS-Units in expInp bestimmen
      offset1 = ((j-1) * noU) + 1;
      if(j < i)
         %Punkt der durch den aktCS inhibierten Units
         start = offset1 + (i-2) * noI;
         expInp(start : (start + noI - 1)) = expInp(start : (start + noI - 1)) + repmat((-1 * aktCS), 1, noI);
      end
      
      if(j > i)
         %Punkt der durch den aktCS inhibierten Units
         start = offset1 + (i-1) * noI;
         expInp(start : (start + noI - 1)) = expInp(start : (start + noI - 1)) + repmat((-1 * aktCS), 1, noI);
      end
   end
   
   %und die entsprechenden Unique-Cues gesetzt werden.
   %Unique Cues sind nur gesetzt fr das gemeinsame auftreten
   %zweier CS.
   if aktCS
       for j = (i+1):noCS
           if csArray(j)
               %den Index der Unique-Cues fr den aktCS ermitteln
               firstUC = absOffset + 1 + (i - 1) * noUCpCS;
               index = firstUC + (j - 2) * noI;
               %das vorhandensein dieser UCs codieren
               expInp(index:(index + noI - 1)) = expInp(index:(index + noI - 1)) + repmat(1, 1, noI);
               
               %den Index der Unique-Cues fr den anderen CS ermitteln
               firstUC = absOffset + 1 + (j - 1) * noUCpCS;
               index = firstUC + (i - 1) * noI;
               %das vorhandensein dieser UCs codieren
               expInp(index:(index + noI - 1)) = expInp(index:(index + noI - 1)) + repmat(1, 1, noI);               
           end
       end
   end   
end

%Nur um sicher zu gehen, dass der Netz-Input ausschlielich
%Nullen und Einsen enthlt...
expInp = expInp > 0;