function expInp = expandInpEstes(csArray, noW, proportions)
%Diese Methode erzeugt aus einem gegebenen Muster-Vektor
%in dem die An- und Abwesenheit der CS kodiert ist, einen
%der Netzspezifikation entsprechenden Input Vektor. Dabei
%bilden die berlegungen von Wagner (2003, Medin-Estes) die
%Grundlage fr die Expansion

%Ein Feld der entsprechenden Lnge anlegen, auf dem man
%dann arbeiten kann.
expInp = [];

noCS = length(csArray);

%Die Anzahl der Elemente pro CS
UpCS = noW/noCS;

for i = 1:noCS
   aktCS = csArray(i);
   restCS = [csArray(1:(i-1)), csArray((i+1):noCS)];
   lRest = noCS-1;
   restCS = restCS(lRest:-1:1);
   offset = (i-1) * UpCS;
   
   %Wenn der CS nicht gesetzt ist sind alle seine Elemente Null
   if ~aktCS
       expInp = [expInp, zeros(1, UpCS)];
   %andernfalls muessen die Units mit den passenden Werten versehen werden
   else
       %der erste ist einfach
       CSinp = [proportions(i, 1)];
       iterations = 2^lRest;
       %Fr den Rest ist ein wenig Index-Arithmetik ntig...
       %Durch die Umwandlung in Binrzahlen ist eine Zuordnung von
       %anwesenden/abwesenden CS zu Positionen im Array der Input-
       %Elemente fr den jeweiligen CS mglich.
       for j = 2:iterations
           %Welche von den restlichen CS werden an
           %der Position j im proportions-Array bercksichtigt?
           bin = dec2bin(j-1, lRest);
           binArray = convertToArray(bin, lRest);
           %Diese CS werden aus dem csArray abgerufen. Abhngig
           %davon, welcher dieser CS gesetzt ist wird (wiederum
           %mit Hilfe von Binrzahlen) das passende Element gesetzt.
           subCS = restCS(binArray > 0);
           lSubCS = length(subCS);
           tmp = zeros(1, 2^lSubCS);
           subCSbin = convertToBin(subCS, lSubCS);
           tmp(bin2Dec(subCSbin) + 1) = proportions(i, j);
           %Jetzt noch die Elemente des aktuellen CS entsprechend erweitern
           CSinp = [CSinp, tmp];
       end
       expInp = [expInp, CSinp];
   end
end

function bA = convertToArray(bin, lBin)
bA = zeros(1, lBin);
for i = 1:lBin
    bA(i) = str2num(bin(i));
end

function b = convertToBin(vec, lVec)
b = [];
for i = 1:lVec
    b = [b, num2str(vec(i))];
end