function init()
%Diese Methode liest die Lerndatei ein und initialisiert die
%Gewichte zwischen der Input- und der Output-Schicht. Vorerst
%wird davon ausgegangen, da (wie bei Konditionierung blich)
%nur ein Ausgabeneuron existiert. Die Datei mit den Lernmustern
%kodiert die An- und Abwesenheit der einzelnen CS. Diese Muster
%werden intern entsprechend der angegebenen Elementkonfiguration
%auf einen Eingabevektor abgebildet. Das Bild dieser Aktion ist
%wie folgt aufgebaut:
%Zuerst sind - in der Reihenfolge der CS - alle Units der einzelnen
%CS aufgefhrt (also noCS * noUpCS viele). Danach werden die Unique-
%Cues der CS-Kombinationen in derselben Reihenfolge aufgefhrt. Falls
%z.B. der erste CS A und der letzte F genannt wird sind die Unique-Cues
%in der Art 'AB AC ... AF BA BC ... BF ..... EA ... EF' angeordnet.
%Dabei werden fr jede Buchstabenkombination noIU viele Elemente
%gespeichert.
global isInit pattern weights noInh noUpCS noCS testPattern

[callObj, callFig] = gcbo;

%zuerst die Anzahl der CS, der Units pro CS und der
%Anzahl der inhibierten Elemente bestimmen um ein Feld
%entsprechender Gre fr die Gewichte anzulegen.
%Dabei ist Anzahl der inhibierten Elemente die Menge
%der Units EINES CS die bei der Kombination gehemmt werden.
csField = findobj(callFig, 'Tag', 'EditText4');
noCS = str2num(get(csField, 'String'));
noUpCS = str2num(get(findobj(callFig, 'Tag', 'EditText8'), 'String'));
noInh = str2num(get(findobj(callFig, 'Tag', 'EditText9'), 'String'));

if(or(or(isempty(noCS), isempty(noUpCS)), isempty(noInh)))
    errordlg ('For initializing, the number of elementary CS, of the units per CS and of the replaced elements is necessary.');
end

if(noCS < 2)
    errordlg ('The model is conceptualized for stimulus compounds, i.e. more than one elementary CS should exist.');
end

if(noUpCS < ((noCS-1)* noInh))
    errordlg ('The number of unit per CS is insufficient, based of the number of replaced elements per CS combination.');
end

noWeights = (noUpCS * noCS) + (noCS - 1) * noInh * noCS;
weights = zeros(1, noWeights);


% und dann die Datei einlesen
%(1) den Pfad holen und die Datei ffnen
pathField = findobj(callFig, 'Tag', 'EditText1');
fileID = fopen(get(pathField, 'String'), 'rt');
if(fileID == -1)
    errordlg ('The pattern file cannot be opened.', 'File error')

end

%(2) Anzahl der Lernmuster bestimmen und eine entsprechende
%Matrix anlegen.
nextLine = fgetl(fileID);
noPat = str2num(nextLine);
pattern = zeros(noPat, (noWeights+1));
tmp = zeros(1, noCS);

%(3)nacheinander alle Muster einlesen und so expandieren,
%da sie dem Netz als Eingabe dienen knnen.
for i = 1:noPat
    nextLine = fgetl(fileID);
    for j = 1:noCS
        [token, nextLine] = strtok(nextLine);
        tmp(j) = str2num(token);
    end
    pattern(i, 1:noWeights) = expandInp(tmp, noUpCS, noInh, noWeights);
    nextLine = fgetl(fileID);
    pattern(i, (noWeights+1)) = str2num(nextLine);
end
fclose(fileID);

%(4) dasselbe Spiel nochmal fr die Testdatendatei (falls eine angegeben
%ist).
pathField = get(findobj(gcbf, 'Tag', 'EditText5'), 'String');

%falls eine Datei angegeben ist lesen wir sie ein und speichern sie in
%testPattern
if(~isempty(pathField))
    [fileID, err] = fopen(pathField, 'rt');
else
    fileID = -1;
end

if(fileID == -1)
    testPattern = [];
else
    %Anzahl der Muster bestimmen und eine entsprechende
    %Matrix anlegen.
    nextLine = fgetl(fileID);
    noPat = str2num(nextLine);
    testPattern = zeros(noPat, (noWeights+1));
    tmp = zeros(1, noCS);

    %nacheinander alle Muster einlesen
    for i = 1:noPat
        nextLine = fgetl(fileID);
        for j = 1:noCS
            [token, nextLine] = strtok(nextLine);
            tmp(j) = str2num(token);
        end
        testPattern(i, 1:noWeights) = expandInp(tmp, noUpCS, noInh, noWeights);
        nextLine = fgetl(fileID);
        testPattern(i, (noWeights+1)) = str2num(nextLine);
    end
    fclose(fileID);
end


%Wenn die Initialisierung erfolgreich war darf gelernt werden.
isInit = 1;

%Um die globalen Variablen auch in anderen Callbacks
%verwenden zu knnen mu man sie derefferenzieren.
clear isInit;
clear pattern;
clear weights;
clear noInh;
clear noUpCS;
clear noCS;
clear testPattern;

%und natrlich die Datei wieder zumachen

return;

function res = fac(n)
if(n == 0)
    res = 1;
else
    res = n * fac(n-1);
end