function initEstes()
%Diese Methode liest die Lerndatei ein und initialisiert die
%Gewichte zwischen der Input- und der Output-Schicht. Vorerst
%wird davon ausgegangen, da (wie bei Konditionierung blich)
%nur ein Ausgabeneuron existiert. Die Datei mit den Lernmustern
%kodiert die An- und Abwesenheit der einzelnen CS. Diese Muster
%werden intern entsprechend der angegebenen Elementkonfiguration
%auf einen Eingabevektor abgebildet.
global isInit pattern weights noCS proportions testPattern

[callObj, callFig] = gcbo;

%zuerst die Anzahl der CS, der Units pro CS und der
%Anzahl der inhibierten Elemente bestimmen um ein Feld
%entsprechender Gre fr die Gewichte anzulegen.
%Dabei ist Anzahl der inhibierten Elemente die Menge
%der Units EINES CS die bei der Kombination gehemmt werden.
csField = findobj(callFig, 'Tag', 'EditText4');
noCS = str2num(get(csField, 'String'));

if isempty(noCS)
   msgbox('Please enter the number of elementary CS!', 'Missing parameter', 'error', 'modal');
   return
end

noWeights = 1;
for i = 1:(noCS - 1)
    noWeights = noWeights + binomCoeff(noCS - 1, i) * (2^i);
end
noWeights = noWeights * noCS;
weights = zeros(1, noWeights);

%(1) Fr replaced elements nach Medin-Estes brauchen wir
% die Proportionen der Ersetzungen, die wir aus einer Datei
% einlesen
pathField = findobj(callFig, 'Tag', 'edit3');
proFileID = fopen(get(pathField, 'String'), 'rt');
if(proFileID == -1)
   msgbox('The proportion file cannot be opened', 'Error', 'error', 'modal');
   return;
end
tmp = zeros(1, noCS - 1);
proportions = zeros(noCS, 2^(noCS - 1));

for i = 1:noCS
    nextLine = fgetl(proFileID);
    for j = 1:(noCS - 1)
      [token, nextLine] = strtok(nextLine);
      tmp(j) = str2num(token);
    end
    proportions(i, :) = getProps(tmp);
end

% und dann noch die Musterdatei einlesen
%(2) den Pfad holen und die Datei ffnen
pathField = findobj(callFig, 'Tag', 'EditText1');
patFileID = fopen(get(pathField, 'String'), 'rt');
if(patFileID == -1)
   errordlg('The pattern file cannot be opened','File error')
   return;
end

%(3) Anzahl der Lernmuster bestimmen und eine entsprechende
%Matrix anlegen.
nextLine = fgetl(patFileID);
noPat = str2num(nextLine);
pattern = zeros(noPat, (noWeights+1));
tmp = zeros(1, noCS);

%(4)nacheinander alle Muster einlesen und so expandieren,
%da sie dem Netz als Eingabe dienen knnen.
for i = 1:noPat
   nextLine = fgetl(patFileID);
   for j = 1:noCS
      [token, nextLine] = strtok(nextLine);
      tmp(j) = str2num(token);
   end
   pattern(i, 1:noWeights) = expandInpEstes(tmp, noWeights, proportions);
   nextLine = fgetl(patFileID);
   pattern(i, (noWeights+1)) = str2num(nextLine);
end

%(5) dasselbe Spiel nochmal fr die Testdatendatei (falls eine angegeben
%ist).
pathField = get(findobj(gcbf, 'Tag', 'EditText5'), 'String');

%falls eine Datei angegeben ist lesen wir sie ein und speichern sie in
%testPattern
if(~isempty(pathField))
   [fileID, err] = fopen(pathField, 'rt');
else
    fileID = -1;
end
   
if(fileID == -1)
    testPattern = [];
else
    nextLine = fgetl(fileID);
    noPat = str2num(nextLine);
    testPattern = zeros(noPat, (noWeights+1));
    tmp = zeros(1, noCS);
    
    for i = 1:noPat
        nextLine = fgetl(fileID);
        for j = 1:noCS
            [token, nextLine] = strtok(nextLine);
            tmp(j) = str2num(token);
        end
        testPattern(i, 1:noWeights) = expandInpEstes(tmp, noWeights, proportions);
        nextLine = fgetl(fileID);
        testPattern(i, (noWeights+1)) = str2num(nextLine);
    end
    fclose(fileID);
end

%Wenn die Initialisierung erfolgreich war darf gelernt werden.
isInit = 1;

%Um die globalen Variablen auch in anderen Callbacks
%verwenden zu knnen mu man sie derefferenzieren.
clear isInit;
clear pattern;
clear weights;
clear noCS;
clear proportions;
clear testPattern;

%und natrlich die Datei wieder zumachen
fclose(patFileID);
fclose(proFileID);

return;

function binom = binomCoeff(n, m)
binom = prod([(m+1):n])/prod(1:(n-m));