function plotOutCourse(course, step, trials, us, USplus, USminus, alpha)
%Diese Funktion generiert eine Figure in welcher der
%Verlauf der Outputs beim Lernen des Modells abgetragen ist. D.h.
%fr jedes der Muster, die in der Testdatei (Im GUI das Feld
%"Pfad der Testdatendatei") angegeben sind, wird ein Verlauf des Outputs,
%den das Modell bei Vorgabe des jeweiligen Musters liefert, geplottet.
%Dabei wird durch die dicke der Linie im Plott signalisiert, ob bei diesem
%Muster -- entsprechend der Testdatei -- eine Reaktion erwartet wird (dicke Linie)
%oder nicht (dnne Linie).
%bergeben werden eine Matrix (course) mit den Outputs zu den
%verschiedenen Zeitpunkten (jede Zeile ein Zeitpunkt) und einen
%Parameter der die Gesamtzahl der Trials angibt (trials) sowie einen
%Parameter der angibt in welchen Abstnden die Gewichte protokolliert
%wurden (step).Letzterer scheint ntig um bei hohen Trialzahlen
%den Speicherbedarf in vertretbarem Rahmen zu halten (s. auch rescWagn.m).
%Als vierter Parameter wird die bei der Darstellung bentigte Erwartung
%bezglich der Reaktion des Netzes (s.o.) bergeben (us).

%Damit die Sachen auch auf einem S/W-Drucker halbwegs manierlich aussehen:
set(0,'DefaultAxesColorOrder',[0 0 0]);
LineStyles = {'-', '--', ':', '-.'};
Markers = {'o', '*', '^'};
stylePointer = 1;
markPointer = 1;
stylePointerUS = 1;
markPointerUS = 1;

[r, c] = size(course);

%Titel der aktuellen Figure
% title = ([' \beta_{US}=', USplus, ', \beta_{nonUS}=', USminus, '; alpha=', alpha]);
%Jetzt die Figure erstellen...
fig = figure('NumberTitle', 'off', 'Name', 'response');
hold;
%Fr jedes Testmuster (d.h. jede Spalte in course)...
lT = {};
iter = 1;
for j = 1:c
    %...den entsprechenden Legendeneintrag erstellen...
    lT(j, 1) = {strcat('T', num2str(j))};
    %...und die Werte zeichnen.
    %augenblicklich knnen maximal 12 verschiedene Testmuster jeweils
    %mit und ohne erwarteten US unterschieden werden (Farbe schwarz;
    %4 Linientypen (s.o.); drei verschiedene Marker).
    if us(j)
        plot(course(:, j), 'LineStyle', LineStyles{stylePointerUS}, 'Marker', Markers{markPointerUS}, 'LineWidth', 2);

        stylePointerUS = stylePointerUS + 1;
        
        if stylePointerUS > 4
            stylePointerUS = 1;
            markPointerUS = markPointerUS + 1;
        end
        
        if markPointerUS > 3
            markPointerUS = 1;
        end
    else
        plot(course(:, j), 'LineStyle', LineStyles{stylePointer}, 'Marker', Markers{markPointer}, 'LineWidth', 0.5);
        
        stylePointer = stylePointer + 1;
        
        if stylePointer > 4
            stylePointer = 1;
            markPointer = markPointer + 1;
        end
        
        if markPointer > 3
            markPointer = 1;
        end
    end
end
hold;
lT = char(lT);

%Zum Schluss noch ein bichen Kosmetik damit die Figure ansehnlicher
%wird:
xlabel('trials'), ylabel('activation');
legend(lT, -1);
autoXTicks = get(gca, 'XTick');
title(['power_{presentUS}=', num2str(USplus), ', power_{absentUS}=', num2str(USminus), '; alpha=', num2str(alpha)]);

%Diese Art der XTickLabel-Berechnung ist nicht ganz unproblematisch scheint
%aber fr die hiesigen Zwecke ausreichend (s. rescWagn).
xtLabel = (autoXTicks  - 1) * step;
set(gca, 'XTickLabel', xtLabel);
