function plotWeigthCourse(course, step, trials)
%Diese Funktion generiert eine oder mehrere Figures in denen der
%Verlauf der Gewichte beim Lernen des Modells abgetragen ist.
%bergeben werden eine Matrix (course) mit den Gewichten zu
%verschiedenen Zeitpunkten (jede Zeile ein Zeitpunkt) und einen
%Parameter der die Gesamtzahl der Trials angibt (trials) sowie einen
%Parameter der angibt in welchen Abstnden die Gewichte protokolliert
%wurden (step).Letzterer scheint ntig um bei hohen Trialzahlen
%den Speicherbedarf in vertretbarem Rahmen zu halten (s. auch rescWagn.m).
%Der bersichtlichkeit halber werden in einer einzigen Figure nicht mehr
%als 6 Gewichte auf einmal dargestellt. Besteht das Modell aus mehr als
%6 Input-Units, so werden die ersten 6 in der ersten Figure, die zweiten
%6 in der zweiten Figure und so weiter abgetragen.

%Damit die Sachen auch auf einem S/W-Drucker halbwegs manierlich aussehen:
set(0,'DefaultAxesColorOrder',[0 0 0],'DefaultAxesLineStyleOrder','-|--|:')

[r, c] = size(course);

%Wieviele Figures brauchen wir?
noFig = ceil(c/6);
%figHandles = [];

%fr jede Figure
for i = 1:noFig
    %Bestimmung der Gewichte die aktuell zu plotten sind
    lowerBound = (i - 1)*6 + 1;
    upperBound = min(i * 6, c);
    %Titel der aktuellen Figure
    title = ['weights ', num2str(lowerBound), ' through ', num2str(upperBound)];
    %Gewichtbezeichnung fr die Legende
    lW = {};
    iter = 1;
    for j = lowerBound:upperBound
        lW(iter, 1) = {strcat('W', num2str(j))};
        iter = iter + 1;
    end
    lW = char(lW);
    %Selektion der Teilmenge der Gewichte
    tmp = course(:, lowerBound:upperBound);
    %figHandles = [figHandles, figure('NumberTitle', 'off', 'Name', title)];
    
    %Jetzt die Figure erstellen...
    fig = figure('NumberTitle', 'off', 'Name', title);
    hold;
    %...und die Gewichtsverlufe zeichnen.
    if (upperBound - lowerBound) < 4
        plot(tmp(:, 1:end), 'Marker', 'x');
    else
        plot(tmp(:, 1:3), 'Marker', 'x');
        plot(tmp(:, 4:end), 'Marker', 'o');
    end
    hold;
    %Zum Schluss noch ein bichen Kosmetik damit die Figure ansehnlicher
    %wird.
    xlabel('trials'), ylabel('associatove strength');
    legend(lW, -1);
    autoXTicks = get(gca, 'XTick');
    %Diese Art der XTickLabel-Berechnung ist nicht ganz unproblematisch scheint
    %aber fr die hiesigen Zwecke ausreichend (s. rescWagn).
    xtLabel = (autoXTicks  - 1) * step;
    set(gca, 'XTickLabel', xtLabel);
end