function rescWagn(noIter, alpha, USplus, USminus)
%Diese Methode lernt das Netz mit den gegebenen Lernmustern
%nach der Rescorla-Wagner-Regel an. 

%auch hier brauchen wir wieder globale Variablen um mit den
%anderen Callbacks kommunizieren zu knnen.
global isInit pattern weights hasLearned testPattern outCourse weightCourse step noTrials

%erstmal gucken ob die zu verwenden Datenstrukturen schon
%existieren, d.h. das Netz schon initialisiert wurde.
if (isInit == 0)
   errordlg('Please initialize a net before learning!')
end

%soll die Darbietung der Lernmuster in jeder Iteration in der Reihenfolge
%in der sie in der Datei aufgefhrt sind erfolgen, oder soll mit jeder
%Iteration zufllig eine neue Reihenfolge erstellt werden?
RO = findobj(gcbf, 'Tag', 'checkbox2');
randomOrder = get(RO, 'Value');
rPattern = pattern;

%Anzahl der Lerndurchgnge, Muster, Input-Units und Lernparameter holen
[noPat, tmp] = size(pattern);
noInp  = tmp-1;
noTest = size(testPattern, 1);

%Datenstrukturen fr die Verlufe anlegen:
%Die maximale Anzahl von Verlaufswerten die gespeichert wird.
MAXIMUM_RECORDED = 100;
%Trialzahl
noTrials = noPat * noIter + 1;
%Gibt es mehr Trials als zu speichernde Verlaufswerte so wird nur jedes
%n-te Trial gespeichert.
step = ceil(noTrials / MAXIMUM_RECORDED);
%Anzahl zu speichernder Verlaufswerte
noRec =  ceil(noTrials / step);
if noTest
    outCourse = zeros(noRec, noTest);
else
    outCourse = [];
end
weightCourse = zeros(noRec, noInp);


%bei jeder Iteration werden alle Muster gelernt...
for i = 1:noIter
    %... falls gewnscht in jeder Iteration in zuflliger Reihenfolge
    %dargeboten ...
    if randomOrder
        rPattern = randomize(pattern);
    end
   for j = 1:noPat
      inp        = rPattern(j, 1:noInp);
      teach      = rPattern(j, noInp+1);
      net        = weights*inp';
      if teach
          weights = weights + (alpha * USplus * (teach - net) * (inp > 0));
      else
          weights = weights + (alpha * USminus * (teach - net) * (inp > 0));          
      end
      %...und nach jedem Muster der Gewichte- und Outputverlauf
      %gespeichert.
      if ~mod((i-1)*noPat + j, step)
          weightCourse((((i-1)*noPat + j) / step) + 1, :) = weights;
          
          if noTest
              for k = 1:noTest
                  outCourse((((i-1)*noPat + j) / step) + 1, k) = weights * testPattern(k, 1:noInp)';
              end
          end
      end
   end
end
%Die beiden folgenden Zuweisungen sollen sicherstellen, dass der Endstand
%des Netzes (d.h. nach dem letzten Trial) in jedem Fall mit gespeichert
%wird. (Wenn das letzte Trial nicht ein vielfaches von step ist geschieht
%das in der Schleife nicht.) Gleichzeitig hat dies zur Folge, dass bei der
%Visualisierung in einer Figure dieser letzte Wert im Zweifel fr eine zu
%hohe Trialzahl (nmlich ein Vielfaches von step) abgetragen wird. Dies
%erscheint jedoch vor dem Hintergrund der hohen Gesamttrialzahl von 100
%(s.o.) ab der ein solches Problem frhestens auftreten kann
%vernachlssigbar. Ganz abgesehen davon kann man sich die tatschliche Zahl
%des letzten Durchgangs einfach als Anzahl der Lernschritte * Anzahl der
%Lernmuster errechnen.
weightCourse(noRec, :) = weights;

if noTest
    for k = 1:noTest
        outCourse(noRec, k) = weights * testPattern(k, 1:noInp)';
    end
end


%wenn alles geklappt hat signalisieren wir das mit
hasLearned = 1;

%und die Globals wieder freigeben
clear isInit;
clear pattern;
clear weights;
clear hasLearned;
clear testPattern;
clear outCourse;
clear weightCourse;
clear step;
clear noTrials;